@@ -21,7 +21,7 @@ from .LuggageInterface import blastParser, spadesTidy
 from collections.abc import Generator
 
 #Doesn't use a file right this second but it will.
-logging.basicConfig(stream = sys.stdout, level=logging.DEBUG)
+logging.basicConfig(stream = sys.stdout, level=logging.INFO)
 LOG = logging.getLogger(__name__)
 
 @dataclass
@@ -211,13 +211,15 @@ class Angua(fileHandler):
 		
 	### Sort and rename contigs
 	def sort_fasta_by_length(self, min_len: int):
+		self.flushFastas()
 		out = self.extendFolder("contigs", f"sorted_{min_len}", str(min_len))
 		for file in self.getFiles("contigs", ".fasta"):
 			sample_name = getSampleName(file, extend=1)
 			output_file = os.path.join(out, 
 									   f"{sample_name}_sorted_{min_len}.fasta")
-			self._toolBelt.filterFasta(file, output_file, "len", min_len)
-	
+			if not os.path.exists(output_file):
+				self._toolBelt.filterFasta(file, output_file, "len", min_len)
+			
 	@check_complete
 	def run_mmseqs2(self, perc, threads: int, in_dir = None,
 											  out_dir = None) -> int:
@@ -417,7 +419,7 @@ class backMapper(blastParser):
 			shutil.rmtree(tmp_dir)
 
 def main():
-	angua_version = 3
+	angua_version = 4
 	options = parse_arguments()
 
 	### Main Pipeline
